Gedcom5Parser class
Class responsible for parsing GEDCOM data
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllFamilies(
RootElement element, Map< String, GedcomElement> elementsMap) → List<FamilyElement> - Returns all families in the provided RootElement based on the elements map from getElementsMap
-
getElementsList(
RootElement element) → List< GedcomElement> - Returns a list containing all elements from within the GEDCOM file
-
getElementsMap(
RootElement element) → Map< String?, GedcomElement> - Returns a map of elements for a given RootElement by its pointer
-
getFamilies(
IndividualElement? individual, Map< String?, GedcomElement> elementsMap, {FamilyRelation relation = FamilyRelation.spouse}) → List<FamilyElement?> - Return family elements listed for an individual
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String data, {bool strict = true}) → RootElement - Parses the string input consisting of GEDCOM lines and returns resulting RootElement having parsed data as its children
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited