compareTo method
Compares this object to another object.
Returns a value like a Comparator when comparing this to other.
That is, it returns a negative integer if this is ordered before other,
a positive integer if this is ordered after other,
and zero if this and other are ordered together.
The other argument must be a value that is comparable to this object.
Implementation
@override
int compareTo(IndividualElement other) {
if (birthDate == null) {
return -1;
}
if (other.birthDate == null) {
return 1;
}
final value = birthDate!.compareTo(other.birthDate!);
if (value == 0) {
return other.name.compareTo(other.name);
}
return value;
}