MermaidDirection enum

Flowchart direction of the rendered Mermaid diagram.

Inheritance
Available extensions

Values

topDown → const MermaidDirection

Top to bottom.

const MermaidDirection('TD')
leftRight → const MermaidDirection

Left to right.

const MermaidDirection('LR')
bottomUp → const MermaidDirection

Bottom to top.

const MermaidDirection('BT')
rightLeft → const MermaidDirection

Right to left.

const MermaidDirection('RL')

Properties

code String
Mermaid flowchart direction code (TD, LR, BT, RL).
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MermaidDirection>
A constant List of the values in this enum, in order of their declaration.