GEDCOM_TAG_CONTINUED top-level constant
String
const GEDCOM_TAG_CONTINUED
An indicator that additional data belongs to the superior value.
The information from the CONT value is to be connected to the
value of the superior preceding line with a carriage return and/or
new line character. Leading spaces could be important to the
formatting of the resultant text. When importing values from CONT
lines the reader should assume only one delimiter character
following the CONT tag. Assume that the rest of the leading
spaces are to be a part of the value.
Implementation
const GEDCOM_TAG_CONTINUED = 'CONT';